@@ -61,7 +61,7 @@ sub import {
     foreach my $sym_name (qw/
         linux freebsd win32 darwin winWSL netbsd openbsd dragonfly
         is cmp_deeply ok done_testing skip isnt time_mark check_mark pass fail cmp_ok like isa_ok unlike diag plan
-        var pipe create_file create_dir move change_file_mtime change_file unlink_file remove_dir subtest new_ok dies_ok catch_run any
+        var pipe create_file create_dir move change_file_mtime change_file unlink_file remove_dir subtest new_ok dies_ok throws_ok catch_run any
     /) {
         no strict 'refs';
         *{"${caller}::$sym_name"} = \&{$sym_name};
